| format_glycan_structure_subset | R Documentation |
Format a Subset of Glycan Structures with Optional Colors
format_glycan_structure_subset(x, indices, colored = TRUE)
x |
A glyrepr_structure object |
indices |
Indices of structures to format |
colored |
A logical value indicating whether to add colors |
A character vector of formatted structures for the specified indices
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.