This function infers the anomer position for concrete or generic monosaccharide names.
Examples
infer_anomer_pos(c("Gal", "Hex", "Neu5Ac"))
#> [1] 1 1 2
This function infers the anomer position for concrete or generic monosaccharide names.
infer_anomer_pos(c("Gal", "Hex", "Neu5Ac"))
#> [1] 1 1 2