| possible_linkages | R Documentation |
Given an obscure linkage format (having "?", e.g. "a2-?"),
this function generates all possible linkages based on the format.
See valid_linkages() for details.
The ranges of possible anomers, first positions, and second positions
can be specified using anomer_range, pos1_range, and pos2_range.
possible_linkages(
linkage,
anomer_range = c("a", "b"),
pos1_range = 1:2,
pos2_range = 1:9,
include_unknown = FALSE
)
linkage |
A linkage string. |
anomer_range |
A character vector of possible anomers.
Default is |
pos1_range |
A numeric vector of possible first positions.
Default is |
pos2_range |
A numeric vector of possible second positions.
Default is |
include_unknown |
A logical value. If |
A character vector of possible linkages.
has_linkages(), remove_linkages(), valid_linkages()
possible_linkages("a2-?")
possible_linkages("??-2")
possible_linkages("a1-3")
possible_linkages("a?-?", pos1_range = 2, pos2_range = c(2, 3))
possible_linkages("?1-6", include_unknown = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.