remove_linkages: Remove All Linkages from a Glycan

View source: R/linkage.R

remove_linkagesR Documentation

Remove All Linkages from a Glycan

Description

This function replaces all graph-edge and floating-part attachment linkages in a glycan structure with "??-?", as well as the reducing end anomer with "??-".

Usage

remove_linkages(glycan)

Arguments

glycan

A glyrepr_structure vector or a glycan igraph.

Value

An object of the same representation as glycan with all linkages removed. Graph input retains its vertex IDs and order.

Examples

glycan <- o_glycan_core_1(linkage = TRUE)
glycan
remove_linkages(glycan)


glyrepr documentation built on Sept. 22, 2026, 5:09 p.m.