View source: R/fill-anomer-pos.R
| fill_anomer_pos | R Documentation |
Add anomer positions to glycan structures with missing anomer position
information. For example, "Gal(??-?)GalNAc(??-" is converted to
"Gal(?1-?)GalNAc(?1-".
fill_anomer_pos(strucs)
strucs |
A |
For anomer positions that are already specified in the input structures, this function does not modify them.
For a structure with floating parts, the reducing-end position is inferred from the root of the main tree. Positions in virtual floating-part attachment linkages are inferred from each floating part's root residue.
An object of the same representation as strucs with anomer
positions added where missing. Graph input retains its vertex IDs and
order.
glycans <- as_glycan_structure(c(
"Gal(??-?)GalNAc(??-",
"Neu5Ac(??-?)Gal(??-?)GalNAc(??-"
))
fill_anomer_pos(glycans)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.