format_glycan_structure_subset: Format a Subset of Glycan Structures with Optional Colors
Description
Format a Subset of Glycan Structures with Optional Colors
Usage
format_glycan_structure_subset(x, indices, colored = TRUE)
Value
A character vector of formatted structures for the specified indices
Arguments
- x
A glyrepr_structure object
- indices
Indices of structures to format
- colored
A logical value indicating whether to add colors