| get_mono_type | R Documentation |
This function determines the type of monosaccharides in character vectors, glycan compositions, or glycan structures. Supported types are "concrete", "generic", and "mixed" (see details below).
get_mono_type(x)
## S3 method for class 'character'
get_mono_type(x)
## S3 method for class 'glyrepr_structure'
get_mono_type(x)
## S3 method for class 'igraph'
get_mono_type(x)
## S3 method for class 'glyrepr_composition'
get_mono_type(x)
x |
Either of these objects:
|
For character input, returns a character vector of the same length as x.
For glyrepr_structure and glyrepr_composition input, returns one
value per element. Missing elements return NA_character_.
For igraph input, returns a character scalar.
Character and structure-vector outputs preserve input names.
There are two types of monosaccharides:
concrete: e.g. "Gal", "GlcNAc", "Glc", "Fuc", etc.
generic: e.g. "Hex", "HexNAc", "HexA", "HexN", etc.
For the full list of monosaccharides, use available_monosaccharides().
Some monosaccharides are special in that they have no generic names in database or literature.
For example, "Mur" is a rare monosaccharide that has no popular generic name.
In glyrepr, we assign a "g" prefix to these monosaccharides as their generic names.
This includes "gNeu", "gKdn", "gPse", "gLeg", "gAci", "g4eLeg", "gBac", "gKdo", "gMur".
These names might only be meaningful inside glycoverse.
Take care when you export results from glycoverse functions to other analysis tools.
convert_to_generic()
# Character vector
get_mono_type(c("Gal", "Hex"))
# Glycan structures
get_mono_type(n_glycan_core(mono_type = "concrete"))
get_mono_type(n_glycan_core(mono_type = "generic"))
# Glycan compositions
comp <- glycan_composition(c(Glc = 2, GalNAc = 1))
get_mono_type(comp)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.