Given an obscure linkage format (having "?", e.g. "a2-?"),
this function generates all possible linkages based on the format.
See valid_linkages() for details.
The ranges of possible anomers, first positions, and second positions
can be specified using anomer_range, pos1_range, and pos2_range.