Skip to contents

This function replaces all graph-edge and floating-part attachment linkages in a glycan structure with "??-?", as well as the reducing end anomer with "??-".

Usage

remove_linkages(glycan)

Arguments

glycan

A glyrepr_structure vector or a glycan igraph.

Value

An object of the same representation as glycan with all linkages removed. Graph input retains its vertex IDs and order.

Examples

glycan <- o_glycan_core_1(linkage = TRUE)
glycan
#> <glycan_structure[1]>
#> [1] Gal(b1-3)GalNAc(a1-
#> # Unique structures: 1
remove_linkages(glycan)
#> <glycan_structure[1]>
#> [1] Gal(??-?)GalNAc(??-
#> # Unique structures: 1