| remove_linkages | R Documentation |
This function replaces all graph-edge and floating-part attachment linkages in a glycan structure with "??-?", as well as the reducing end anomer with "??-".
remove_linkages(glycan)
glycan |
A glyrepr_structure vector or a glycan |
An object of the same representation as glycan with all linkages
removed. Graph input retains its vertex IDs and order.
glycan <- o_glycan_core_1(linkage = TRUE)
glycan
remove_linkages(glycan)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.