Learn R Programming

glyrepr (version 0.10.1)

remove_linkages: Remove All Linkages from a Glycan

Description

This function replaces all linkages in a glycan structure with "??-?", as well as the reducing end anomer with "??-".

Usage

remove_linkages(glycan)

Value

A glyrepr_structure vector with all linkages removed.

Arguments

glycan

A glyrepr_structure vector.

Examples

Run this code
glycan <- o_glycan_core_1(linkage = TRUE)
glycan
remove_linkages(glycan)

Run the code above in your browser using DataLab