powered by
This function replaces all linkages in a glycan structure with "??-?", as well as the reducing end anomer with "??-".
remove_linkages(glycan)
A glyrepr_structure vector with all linkages removed.
A glyrepr_structure vector.
glycan <- o_glycan_core_1(linkage = TRUE) glycan remove_linkages(glycan)
Run the code above in your browser using DataLab