| remove_substituents | R Documentation |
This function replaces all vertex substituents in a glycan structure with empty strings and removes unresolved floating substituents.
remove_substituents(glycan)
glycan |
A glyrepr_structure vector or a glycan |
An object of the same representation as glycan with all
substituents removed. Graph input retains its vertex IDs and order.
(glycan <- o_glycan_core_1())
remove_substituents(glycan)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.